Attribute VB_Name = "modGetData"
Option Explicit

Public Function ConnectPort(ByRef io As MSComm, _
                            ByVal Port As Integer, _
                            Optional ByRef ErrDescription As String) As Boolean

' Establish connection using Port number
' Test connection by calling for timer value and test for the returned byte


    Dim DataIn As Variant
    Dim DataOut As Variant

    On Error GoTo Errorhandler:

    ErrDescription = ""

    With io
        ' Close port if open so we can change the settings
        If .PortOpen = True Then
            .PortOpen = False
        End If

        ' 9600 baud, no parity, 8 data, and 1 stop bit.
        .Settings = "9600,N,8,1"

        ' Tell the control to read entire buffer when Input
        ' is used.
        .InputLen = 0

        ' Set to selected COM port
        .CommPort = Port

        ' Use binary as input
        .InputMode = comInputModeBinary

        .PortOpen = True

        .Output = "C"  ' Send command to get the timer value 0 to 255

        ' 50ms delay
        delay 50

        If .InBufferCount > 0 Then
            ConnectPort = True
            ' Write to immediate window
            Debug.Print "buffer count = "; io.InBufferCount
            DataIn = .Input     ' grab data from comm port.
            Debug.Print "Input = "; DataIn(0)
        Else
            ConnectPort = False
            Debug.Print "buffer count = "; io.InBufferCount
            If .PortOpen = True Then
                .PortOpen = False
            End If

        End If

    End With

    Exit Function
Errorhandler:
    ErrDescription = "ConnectPort Error: " & Err.Description
    Debug.Print ErrDescription & vbCrLf

End Function
Public Sub GetVariables(ByRef io As MSComm, _
                        ByRef DataIn As Variant)

    On Error GoTo Errorhandler:

' Tell the control to read entire buffer when Input
' is used.
    io.InputLen = 0

    ' Send command to MS as text
    io.InputMode = comInputModeBinary

    ' Send the commands to get a page
    io.Output = "A"

    ' wait 200 ms
    delay 200

    ' Print to immediate window the buffer size
    Debug.Print "buffer count = "; io.InBufferCount
    DataIn = io.Input     ' grab data from comm port.

    Exit Sub
Errorhandler:
    Debug.Print "sub GetVariables, Error: "; Err.Description
End Sub
Public Sub GetTable(ByRef io As MSComm, _
                    ByRef DataIn As Variant, ByVal tbl As Table)

    Dim DataOut As Variant
    Dim byteArray() As Byte


    On Error GoTo Errorhandler:

    ' Tell the control to read entire buffer when Input
    ' is used.
    io.InputLen = 0

    ' Send command to MS as array of bytes
    io.InputMode = comInputModeBinary

    ReDim byteArray(2)
    ' Select a page
    byteArray(0) = Asc("P")
    byteArray(1) = TableIndex(tbl, modGlobal.TBL_PAGE)
    byteArray(2) = Asc("V")
    DataOut = byteArray


    ' Send the commands to get a page and return the variables
    io.Output = DataOut

    ' wait 1 sec
    delay 1000

    ' Print to immediate window the buffer size
    Debug.Print "buffer count = "; io.InBufferCount
    DataIn = io.Input     ' grab data from comm port.

Errorhandler:
    Debug.Print Err.Description
End Sub


Public Function GetSignature(ByRef io As MSComm, _
                             Optional ByRef ErrDescription As String) As String
' Gets the description and version of firmware (Signature)
    Dim DataIn As Variant

    On Error GoTo SignatureError
    With io
        ' Use text as input
        .InputMode = comInputModeText

        ' Send command to get the Signature
        .Output = "S"

        ' 50ms delay
        delay 50

        ' Write to immediate window
        Debug.Print "buffer count = "; io.InBufferCount

        ' Test for data in the input buffer
        If .InBufferCount > 0 Then
            DataIn = .Input     ' grab data from comm port.
            Debug.Print "Signature = "; DataIn
            GetSignature = DataIn
        Else
            If .PortOpen = True Then
                .PortOpen = False
            End If
        End If

    End With


    Exit Function
SignatureError:
    ErrDescription = Err.Description
    Debug.Print "Sub GetSignature Error: "; ErrDescription
End Function

Public Function GetString(ByRef io As MSComm, ByVal cmd As String, _
                          Optional ByRef ErrDescription As String) As String
' Gets a string for commands that return a string
    Dim DataIn As Variant

    On Error GoTo SignatureError

    With io
        ' Use text as input
        .InputMode = comInputModeText

        ' Send command to get the Signature
        .Output = cmd

        ' 50ms delay
        delay 50

        ' Write to immediate window
        Debug.Print "buffer count = "; io.InBufferCount

        If .InBufferCount > 0 Then
            DataIn = .Input     ' grab data from comm port.
            Debug.Print "Signature = "; DataIn
            GetString = DataIn
        Else
            If .PortOpen = True Then
                .PortOpen = False
            End If
        End If

    End With


    Exit Function
SignatureError:
    ErrDescription = Err.Description
    Debug.Print "Sub GetSignature Error: "; ErrDescription
End Function

Public Sub ChangeTable(ByRef io As MSComm, ByVal TblValue As Byte, _
                       ByVal tbl As Table)
' Using the "W" command write a new value to the table.
' Before sending the "W" command the page for the
' required table is set
    Dim DataOut As Variant
    Dim byteArray() As Byte


    On Error GoTo Errorhandler:

    ' Send command to MS as array of bytes
    io.InputMode = comInputModeBinary

    ReDim byteArray(4)

    ' Set the page of the table
    byteArray(0) = Asc("P")
    byteArray(1) = TableIndex(tbl, modGlobal.TBL_PAGE)

    ' Write the table value to the start position in table
    byteArray(2) = Asc("W")
    byteArray(3) = TableIndex(tbl, modGlobal.TBL_START)
    byteArray(4) = TblValue
    DataOut = byteArray


    ' Send the commands to set the page and send the
    ' table value
    io.Output = DataOut

    delay 100

Errorhandler:
    Debug.Print Err.Description
End Sub

